# LOCUTIUS

Adapted from Adam Bard's work at https://unpythonic.com/02_02_multimethods/,
with clarifications, corrections, and unit tests.

Clojure-style multimethods with arbitrary dispatch keys. See 'test_locutius.py'
for usage examples.


## INSTALLATION

    pip install locutius

Requires Python 3, preferably 3.6 or later.
